@@ -15,7 +15,7 @@ let tasks = new Map();
 let image_tasks = new Map();
 
 let queue = new taskcluster.Queue({
-  baseUrl: "http://taskcluster/queue/v1/"
+  baseUrl: "http://taskcluster/queue/v1"
 });
 
 function fromNow(hours) {
@@ -80,6 +80,7 @@ function parseTreeherder(def) {
 }
 
 function convertTask(def) {
+  let scopes = [];
   let dependencies = [];
 
   let env = merge({
@@ -110,19 +111,24 @@ function convertTask(def) {
     payload.image = def.image;
   }
 
-  if (def.features) {
-    payload.features = parseFeatures(def.features);
-  }
-
   if (def.artifacts) {
     payload.artifacts = parseArtifacts(def.artifacts);
   }
 
+  if (def.features) {
+    payload.features = parseFeatures(def.features);
+
+    if (payload.features.allowPtrace) {
+      scopes.push("docker-worker:feature:allowPtrace");
+    }
+  }
+
   return {
     provisionerId: def.provisioner || "aws-provisioner-v1",
     workerType: def.workerType || "hg-worker",
     schedulerId: "task-graph-scheduler",
 
+    scopes,
     created: fromNow(0),
     deadline: fromNow(24),
 
